@@ -12,7 +12,7 @@ our @EXPORT_OK = qw( new      ) ;
 our @Export    = qw( new      ) ;
 
 use vars qw( $VERSION )         ;
-$VERSION =                       '0.11' ;
+$VERSION =                       '0.13' ;
 
 sub new        { shift and return bless { @_, 'timestamp'=>time }                    }
 
@@ -58,8 +58,10 @@ sub trailing   {
 sub com_str    { return $_[0]->{ 'com_str'  } = $_[1] || $_[0]->{ 'com_str'  } }
 sub userhost   { warn 'TODO: userhost for '. ref $_[0]                         }
 
+# FIXME !!!
 *to = \&middle;
 
+*parent = \&Net::IRC2::Connection::parent;
 
 sub convert {
     my %hash = (
@@ -137,32 +139,8 @@ sub convert {
     return $hash{$_[0]} ;
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 1;
 
-
-
-
-
-
-
 __END__
 
 =head1 NAME
@@ -181,6 +159,10 @@ Documentation in progress ...
 
 =item new()
 
+=item parent()
+
+return the Net::IRC2::Connection parent object
+
 =item dump()
 
 Print a nice formated dump of the Event
